Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
arrakis/__init__.py | 15 | 3 | 0 | 80.0%
arrakis/__main__.py | 158 | 63 | 0 | 60.1%
arrakis/api.py | 15 | 1 | 0 | 93.3%
arrakis/block.py | 226 | 29 | 3 | 87.2%
arrakis/channel.py | 66 | 4 | 2 | 93.9%
arrakis/client.py | 94 | 4 | 0 | 95.7%
arrakis/constants.py | 8 | 0 | 0 | 100.0%
arrakis/flight.py | 123 | 8 | 3 | 93.5%
arrakis/mux.py | 80 | 23 | 0 | 71.2%
arrakis/publish.py | 87 | 10 | 57 | 88.5%
Total | 872 | 145 | 65 | 83.4%

No items found using the specified filter.